@@ -16,6 +16,9 @@ else
     GZIP_CMD="cat"
 fi
 
+DPY="$DISPLAY"
+[ "$DPY" ] || DPY=":0"
+
 set_filename() {
     if [ "$GZIP_CMD" = "gzip -c" ]; then
         LOG_FILENAME="$BASE_LOG_FILENAME.gz"
@@ -47,7 +50,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 14225374 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 15788577 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -145,6 +148,20 @@ append_glob() {
     done
 }
 
+#
+# append_file_or_dir_silent() - if $1 is a regular file, append it; otherwise,
+# if $1 is a directory, append all files under it.  Don't print anything if the
+# file does not exist.
+#
+
+append_file_or_dir_silent() {
+    if [ -f "$1" ]; then
+        append "$1"
+    elif [ -d "$1" ]; then
+        append_glob "$1/*"
+    fi
+}
+
 #
 # append_sysctl() - use sysctl to retrieve the value of interesting
 # kernel or driver state variables.
@@ -292,6 +309,25 @@ for log_basename in /var/log/XFree86 /var/log/Xorg; do
     done
 done
 
+# Append any config files found in home directories
+cat /etc/passwd \
+    | cut -d : -f 6 \
+    | sort | uniq \
+    | while read DIR; do
+        append_file_or_dir_silent "$DIR/.nv/nvidia-application-profiles-rc"
+        append_file_or_dir_silent "$DIR/.nv/nvidia-application-profiles-rc.backup"
+        append_file_or_dir_silent "$DIR/.nv/nvidia-application-profiles-rc.d"
+        append_file_or_dir_silent "$DIR/.nv/nvidia-application-profiles-rc.d.backup"
+        append_silent "$DIR/.nv/nvidia-application-profile-globals-rc"
+        append_silent "$DIR/.nv/nvidia-application-profile-globals-rc.backup"
+        append_silent "$DIR/.nvidia-settings-rc"
+    done
+
+# Capture global app profile configs
+append_file_or_dir_silent "/etc/nvidia/nvidia-application-profiles-rc"
+append_file_or_dir_silent "/etc/nvidia/nvidia-application-profiles-rc.d"
+append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
+
 # append vmstat info
 
 (
@@ -450,9 +486,7 @@ done
     echo "nvidia-settings -q all:"
     echo ""
 
-    DPY="$DISPLAY"
-    [ "$DPY" ] || DPY=":0"
-    DISPLAY= nvidia-settings -c "$DPY" -q all 2>&1 & sleep 1 ; kill -9 $! > /dev/null 2>&1    
+    DISPLAY= nvidia-settings -c "$DPY" -q all 2>&1 & sleep 1 ; kill -9 $! > /dev/null 2>&1
 
     if [ $? -eq 0 ]; then
         # The nvidia-settings process is still there.
@@ -460,6 +494,27 @@ done
     fi
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+# In case of failure, if xrandr returns with delay, we print the
+# message from check "$?" & if it returns error immediately before kill,
+# we directly write the error to the log file.
+
+(
+    if [ -x "`which xrandr 2>/dev/null`" ] ; then
+         echo "____________________________________________"
+         echo ""
+         echo "xrandr --verbose:"
+         echo ""
+
+         xrandr -display $DPY --verbose 2>&1 & sleep 1 ; kill -9 $! > /dev/null 2>&1
+         if [ $? -eq 0 ]; then
+             # The xrandr process is still there.
+             echo "xrandr could not connect to an X server"
+         fi
+    else
+        echo "Skipping xrandr output (xrandr not found)"
+    fi
+) | $GZIP_CMD >> $LOG_FILENAME
+
 (
     echo "____________________________________________"
 
