@@ -153,12 +153,20 @@ typedef struct nv_ioctl_free_os_event
     NvU32 Status;
 } nv_ioctl_free_os_event_t;
 
+#define NV_CTL_DEVICE_PCI_DOMAIN        0
+#define NV_CTL_DEVICE_PCI_BUS           255
+#define NV_CTL_DEVICE_PCI_SLOT          255
+
+#define NV_PCI_MATCH_CTL_DEVICE(domain, bus, slot) \
+    (((domain) == NV_CTL_DEVICE_PCI_DOMAIN) && \
+     ((bus) == NV_CTL_DEVICE_PCI_BUS) && ((slot) == NV_CTL_DEVICE_PCI_SLOT))
+
 /* status code */
 typedef struct nv_ioctl_status_code
 {
     NvU32 domain;
-    NvU32 bus;
-    NvU32 slot;
+    NvU8  bus;
+    NvU8  slot;
     NvU32 status;
 } nv_ioctl_status_code_t;
 
@@ -203,6 +211,8 @@ typedef union
 #define NVRM_PCICFG_BAR_MEMTYPE_64BIT   0x00000004
 #define NVRM_PCICFG_BAR_ADDR_MASK       0xfffffff0
 
+#define NVRM_PCICFG_NUM_DWORDS          64
+
 #define NV_GPU_NUM_BARS                 3
 #define NV_GPU_BAR_INDEX_REGS           0
 #define NV_GPU_BAR_INDEX_FB             1
@@ -282,7 +292,7 @@ typedef struct
     NvU32 gpu_id;
     void *handle;
 
-    NvU32 pci_cfg_space[16];
+    NvU32 pci_cfg_space[NVRM_PCICFG_NUM_DWORDS];
 
     /* physical characteristics */
     nv_aperture_t bars[NV_GPU_NUM_BARS];
@@ -497,7 +507,7 @@ RM_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, NvU64, void *);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
-void*  NV_API_CALL  nv_get_adapter_state         (NvU32, NvU16, NvU16);
+void*  NV_API_CALL  nv_get_adapter_state         (NvU32, NvU8, NvU8);
 
 void   NV_API_CALL  nv_set_dma_address_size      (nv_state_t *, NvU32 );
 
@@ -541,6 +551,7 @@ RM_STATUS  NV_API_CALL  nv_nvmap_get_page_list_info (NvU32, NvU32 *, NvU32 *, Nv
 RM_STATUS  NV_API_CALL  nv_nvmap_get_page_list   (nv_state_t *, void *, NvU64, NvU64 *, void **, NvU32);
 RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *, void *, NvU32);
 #endif
+RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 
 /*
  * ---------------------------------------------------------------------------
