@@ -456,15 +456,6 @@ NvU32 NV_API_CALL os_string_length(const char* s)
     return strlen(s);
 }
 
-RM_STATUS NV_API_CALL os_strncpy_from_user(
-    char *dst,
-    const char *src,
-    NvU32 n
-)
-{
-    return copyinstr(src, dst, n, NULL) ? RM_ERR_INVALID_POINTER : RM_OK;
-}
-
 NvU32 NV_API_CALL os_get_page_size(void)
 {
     return PAGE_SIZE;
@@ -485,6 +476,11 @@ NvU32 NV_API_CALL os_get_cpu_count(void)
     return mp_ncpus;
 }
 
+NvU32 NV_API_CALL os_get_cpu_number(void)
+{
+    return curcpu;
+}
+
 #ifdef NV_USE_WBINVD
 static void wbinvd_action_func(void *arg)
 {
@@ -684,6 +680,16 @@ BOOL NV_API_CALL os_is_efi_enabled(void)
     return FALSE;
 }
 
+RM_STATUS NV_API_CALL os_get_efi_screen_info(
+    NvU64 *pPhysicalAddress,
+    NvU32 *pWidth,
+    NvU32 *pHeight,
+    NvU32 *pBpp
+)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
+
 void NV_API_CALL os_register_compatible_ioctl(
     NvU32 cmd,
     NvU32 size
@@ -775,3 +781,8 @@ RM_STATUS NV_API_CALL os_get_version_info(os_version_info * pOsVersionInfo)
 {
     return RM_ERR_NOT_SUPPORTED;
 }
+
+NvBool NV_API_CALL os_is_xen_dom0(void)
+{
+    return FALSE;
+}
