@@ -81,7 +81,6 @@ NvU64       NV_API_CALL  os_get_cpu_frequency        (void);
 NvU32       NV_API_CALL  os_get_current_process      (void);
 RM_STATUS   NV_API_CALL  os_get_current_thread       (NvU64 *);
 char*       NV_API_CALL  os_string_copy              (char *, const char *);
-RM_STATUS   NV_API_CALL  os_strncpy_from_user        (char *, const char *, NvU32);
 NvU32       NV_API_CALL  os_string_length            (const char *);
 NvS32       NV_API_CALL  os_snprintf                 (char *, NvU32, const char *, ...);
 void        NV_API_CALL  os_log_error                (NvU32, NvU32, const char *, va_list);
@@ -116,6 +115,7 @@ void        NV_API_CALL  os_dbg_init                 (void);
 void        NV_API_CALL  os_dbg_breakpoint           (void);
 void        NV_API_CALL  os_dbg_set_level            (NvU32);
 NvU32       NV_API_CALL  os_get_cpu_count            (void);
+NvU32       NV_API_CALL  os_get_cpu_number           (void);
 RM_STATUS   NV_API_CALL  os_alloc_smp_barrier        (void);
 RM_STATUS   NV_API_CALL  os_free_smp_barrier         (void);
 RM_STATUS   NV_API_CALL  os_raise_smp_barrier        (void);
@@ -148,6 +148,8 @@ BOOL        NV_API_CALL  os_is_isr                   (void);
 BOOL        NV_API_CALL  os_pat_supported            (void);
 void        NV_API_CALL  os_dump_stack               (void);
 BOOL        NV_API_CALL  os_is_efi_enabled           (void);
+NvBool      NV_API_CALL  os_is_xen_dom0              (void);
+RM_STATUS   NV_API_CALL  os_get_efi_screen_info      (NvU64 *, NvU32 *, NvU32 *, NvU32 *);
 
 /*
  * ---------------------------------------------------------------------------
@@ -180,7 +182,7 @@ int  NV_API_CALL  nv_printf(NvU32 debuglevel, const char *printf_format, ...);
 void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 
 #define NV_MEMORY_TYPE_SYSTEM       0
-#define NV_MEMORY_TYPE_AGP          1
+// #define NV_MEMORY_TYPE_AGP          1
 #define NV_MEMORY_TYPE_REGISTERS    2
 #define NV_MEMORY_TYPE_FRAMEBUFFER  3
 
@@ -217,4 +219,6 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define RM_PAGES_TO_OS_PAGES(count) (((count) + RM_PAGES_PER_OS_PAGES - 1) \
                                        / RM_PAGES_PER_OS_PAGES)
 
+#define IS_VGX_HYPER()              os_is_xen_dom0()
+
 #endif /* _OS_INTERFACE_H_ */
